MovingClock \_ 生成动态时钟
==================================

|License| |Pypi| |Author| |Github|

安装方法
--------

通过 pip 直接安装

::

   pip install MovingClock

更新

::

   pip install MovingClock --upgrade

使用方法
--------

导入

::

   import MovingClock

使用

::

   MovingClock.main()

**！注意事项！**

import MovingClock √

import movingclock ×

关于作者
--------
Author

*Jason4zh*

Email

*13640817984@163.com*

Package

*https://pypi.org/project/MovingClock/*


::

   print("Thank you for using!")

.. |License| image:: https://img.shields.io/pypi/l/MovingClock
   :target: https://github.com/Jason4zh/MovingClock/blob/main/LICENSE.txt
.. |Pypi| image:: https://img.shields.io/badge/pypi-v2.0.0-green
   :target: https://pypi.org/project/MovingClock
.. |Author| image:: https://img.shields.io/badge/Author-Jason4zh-blue
   :target: https://pypi.org/user/Jason4zh
.. |Github| image:: https://img.shields.io/badge/Github-Jason4zh-red
   :target: https://github.com/Jason4zh/MovingClock
